# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚚 Rename `upload_docs_dir` to `upload_docs_artifact` |  | 2023-03-21 | 0.3.4
🍱 Track images in docs | [11](https://github.com/laminlabs/laminci/pull/11) | [falexwolf](https://github.com/falexwolf) | 2023-03-12 | 0.3.2
➖ Remove dependency on lamindb in laminci | [10](https://github.com/laminlabs/laminci/pull/10) | [falexwolf](https://github.com/falexwolf) | 2023-03-09 | 0.3.0 / 0.3.1
🍱 Track readme in docs upload | [9](https://github.com/laminlabs/laminci/pull/9) | [falexwolf](https://github.com/falexwolf) | 2023-03-06 | 0.2.5
🐛 Implement overwrite | [8](https://github.com/laminlabs/laminci/pull/8) | [falexwolf](https://github.com/falexwolf) | 2023-02-28 | 0.2.4
:zap: Only include docs files | [7](https://github.com/laminlabs/laminci/pull/7) | [falexwolf](https://github.com/falexwolf) | 2023-02-27 | 0.2.3
🐛 Fix coverage call | [6](https://github.com/laminlabs/laminci/pull/6) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.2
🚸 Make coverage calculation optional | [5](https://github.com/laminlabs/laminci/pull/5) | [falexwolf](https://github.com/falexwolf) | 2023-02-24 | 0.2.1
✨ Move docs | [4](https://github.com/laminlabs/laminci/pull/4) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.2.0
🐛 Fix | [3](https://github.com/laminlabs/laminci/pull/3) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.1
🚚 Move code from lndb | [2](https://github.com/laminlabs/laminci/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 | 0.1.0
🔥 Remove unnecessary files | [1](https://github.com/laminlabs/laminci/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-02-23 |
